DynList
A linked list that can have dynamically sized types in their nodes.
use core::fmt::Debug;
use dyn_list::DynList;
let mut list = DynList::<dyn Debug>::new();
list.push_back_unsize("Hello, World");
list.push_back_unsize(0);
list.push_back_unsize([1, 2, 3, 4]);
println!("{list:?}");This crate currently only works on the nightly channel.
TODO
This library is still in development and breaking changes may occur.
- Comment
unsafeblocks. - Add tests.
License
DynList is dual-licensed under either the Apache License Version 2.0 or MIT license at your option.
Modules
Structs
- A doubly-linked list that allows nodes with dynamically sized types.
- A node with possibly uninitialised data.